<template>
  <div class="riskBox">
    <el-form ref="formRef" :model="state.formData" :rules="state.rules" class="register-form" label-position="top">
      <el-row :gutter="30">
        <el-col :span="6">
          <el-form-item prop="contractSignDate" label="合同签订日期">
            <el-date-picker
                style="width: 100%"
                v-model="state.formData.contractSignDate"
                type="date"
                value-format="YYYY-MM-DD 00:00:00"
                placeholder="选择日期"
                size="large"
            />
          </el-form-item>
        </el-col>
        <el-col :span="18">
          <el-form-item prop="contractMoney">
            <template #label>
              项目合同额<span style="font-size: 13px;color: red;font-weight: normal;display: inline-block;margin-left: 6px" @input="state.formData.contractMoney= state.formData.contractMoney.replace(/[^\d|\.]/g,'')"
            >预估合同金额，归档阶段可以进行修改。仅支持数字，单位万元，小数点后最多两位，数值范围（0.01-999.99）</span>
            </template>
            <el-input

                v-model="state.formData.contractMoney"
                size="large"
                placeholder="请输入项目合同额"
                @input="state.formData.contractMoney= state.formData.contractMoney.replace(/[^0-9.\/\-]/g,'')"

            >
              <template #append>万元</template>
            </el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-form-item label="项目合同额说明">
        <el-input
            v-model="state.formData.contractIntroduction"
            :autosize="{ minRows: 6 }"
            maxlength="100"
            show-word-limit
            type="textarea">
        </el-input>
      </el-form-item>
    </el-form>
  </div>

</template>
<script setup>

import {defineEmits, onMounted, reactive, ref} from "vue";
import {ElMessage} from "element-plus";
import {addRecord, editRecord, getDetail} from "@/api/projectManage/contractMng";
import Cookies from "js-cookie";
const emit = defineEmits(["getNextStatus"]);

const state = reactive({
  formData: {
    id: '',
    projectId: null,
    contractSignDate: '',
    contractMoney: '',
    contractIntroduction: ''
  },
  rules: {
    contractSignDate: [{required: true, message: '请选择合同签订日期', trigger: 'blur'}],
    contractMoney: [{required: true, message: '请输入项目合同额', trigger: 'blur'}]
  }
})

const isAmin = ref(false)
const formRef = ref();
onMounted(() => {
  const userInfo = JSON.parse(Cookies.get('userInfo'))
  if(userInfo.identity === 0){
    isAmin.value = true;
  }
});

const riskOpen = async (type,val) => {
  state.formData.projectId = val;
  if(type === 'detail' || type === 'edit' ){
    const res = await getDetail({projectId: val});
    if(res.code == 200){
      if(res.data){
        state.formData = res.data;
      }
    }else {
      ElMessage.warning(res.message)
    }
  }
  if(type === 'add' || type === 'clickEdit') {
    const valid = await formRef.value.validate();
    if(valid){
      if (isAmin.value) {
        ElMessage.warning("当前用户暂无权限");
        return;
      }
      if(type === 'add'){
        const {id, ...data} = JSON.parse(JSON.stringify(state.formData))
        const res = await addRecord(data);
        if (res.code == 200) {
          ElMessage.success('保存成功')
          formRef.value.clearValidate();
          emit('getNextStatus', state.formData.projectId);
        } else {
          ElMessage.warning(res.message)
        }
      }else if(type === 'clickEdit'){
        const { ...data} = JSON.parse(JSON.stringify(state.formData))
        const res = await editRecord(data);
        if (res.code == 200) {
          ElMessage.success('变更成功')
          formRef.value.clearValidate();
          // emit('getNextStatus', data.project.id);
        } else {
          ElMessage.warning(res.message)
        }
      }
    }
  }
}

defineExpose({
  riskOpen
});


</script>
<style scoped lang="scss">
.riskBox{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
}

</style>
